@@ -81,7 +81,9 @@ class JediLanguageServerProtocol(LanguageServerProtocol):
         server: "JediLanguageServer" = self._server
         try:
             server.initialization_options = InitializationOptions.parse_obj(
-                params.initialization_options
+                {}
+                if params.initialization_options is None
+                else params.initialization_options
             )
         except ValidationError as error:
             msg = f"Invalid InitializationOptions, using defaults: {error}"
@@ -486,7 +488,9 @@ def code_action(
             )
         )
 
-    extract_var = jedi_utils.random_var("var_")
+    extract_var = (
+        server.initialization_options.code_action.name_extract_variable
+    )
     try:
         extract_variable_refactoring = jedi_script.extract_variable(
             new_name=extract_var, **jedi_lines_extract
@@ -508,7 +512,9 @@ def code_action(
             )
         )
 
-    extract_func = jedi_utils.random_var("func_")
+    extract_func = (
+        server.initialization_options.code_action.name_extract_function
+    )
     try:
         extract_function_refactoring = jedi_script.extract_function(
             new_name=extract_func, **jedi_lines_extract
